# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/databricks_api/permissions__client.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5tecton_proto/databricks_api/permissions__client.proto\x12\x1btecton_proto.databricks_api\"\xb5\x01\n\x16GroupPermissionsObject\x12\x1d\n\ngroup_name\x18\x01 \x01(\tR\tgroupName\x12)\n\x10permission_level\x18\x02 \x01(\tR\x0fpermissionLevel\x12\x1b\n\tuser_name\x18\x03 \x01(\tR\x08userName\x12\x34\n\x16service_principal_name\x18\x04 \x01(\tR\x14servicePrincipalName\"\x8f\x01\n\x10PermissionObject\x12)\n\x10permission_level\x18\x01 \x01(\tR\x0fpermissionLevel\x12\x1c\n\tinherited\x18\x02 \x01(\x08R\tinherited\x12\x32\n\x15inherited_from_object\x18\x03 \x03(\tR\x13inheritedFromObject\"\x88\x02\n\x19\x41\x63\x63\x65ssControlListResponse\x12\x1b\n\tuser_name\x18\x01 \x01(\tR\x08userName\x12\x1d\n\ngroup_name\x18\x02 \x01(\tR\tgroupName\x12\x34\n\x16service_principal_name\x18\x03 \x01(\tR\x14servicePrincipalName\x12!\n\x0c\x64isplay_name\x18\x04 \x01(\tR\x0b\x64isplayName\x12V\n\x0f\x61ll_permissions\x18\x05 \x03(\x0b\x32-.tecton_proto.databricks_api.PermissionObjectR\x0e\x61llPermissions\"y\n\x12PermissionsRequest\x12\x63\n\x13\x61\x63\x63\x65ss_control_list\x18\x01 \x03(\x0b\x32\x33.tecton_proto.databricks_api.GroupPermissionsObjectR\x11\x61\x63\x63\x65ssControlList\"\xc1\x01\n\x13PermissionsResponse\x12\x1b\n\tobject_id\x18\x01 \x01(\tR\x08objectId\x12\x1f\n\x0bobject_type\x18\x02 \x01(\tR\nobjectType\x12\x66\n\x13\x61\x63\x63\x65ss_control_list\x18\x04 \x03(\x0b\x32\x36.tecton_proto.databricks_api.AccessControlListResponseR\x11\x61\x63\x63\x65ssControlListJ\x04\x08\x03\x10\x04\x42\x1d\n\x19\x63om.tecton.databricks_apiP\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tecton_proto.databricks_api.permissions__client_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.tecton.databricks_apiP\001'
  _GROUPPERMISSIONSOBJECT._serialized_start=87
  _GROUPPERMISSIONSOBJECT._serialized_end=268
  _PERMISSIONOBJECT._serialized_start=271
  _PERMISSIONOBJECT._serialized_end=414
  _ACCESSCONTROLLISTRESPONSE._serialized_start=417
  _ACCESSCONTROLLISTRESPONSE._serialized_end=681
  _PERMISSIONSREQUEST._serialized_start=683
  _PERMISSIONSREQUEST._serialized_end=804
  _PERMISSIONSRESPONSE._serialized_start=807
  _PERMISSIONSRESPONSE._serialized_end=1000
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/databricks_api/instance_profiles__client.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;tecton_proto/databricks_api/instance_profiles__client.proto\x12\x1btecton_proto.databricks_api\"y\n\x1cInstanceProfilesListResponse\x12Y\n\x11instance_profiles\x18\x01 \x03(\x0b\x32,.tecton_proto.databricks_api.InstanceProfileR\x10instanceProfiles\"C\n\x0fInstanceProfile\x12\x30\n\x14instance_profile_arn\x18\x01 \x01(\tR\x12instanceProfileArnB\x1d\n\x19\x63om.tecton.databricks_apiP\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tecton_proto.databricks_api.instance_profiles__client_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.tecton.databricks_apiP\001'
  _INSTANCEPROFILESLISTRESPONSE._serialized_start=92
  _INSTANCEPROFILESLISTRESPONSE._serialized_end=213
  _INSTANCEPROFILE._serialized_start=215
  _INSTANCEPROFILE._serialized_end=282
# @@protoc_insertion_point(module_scope)
